list_user_data_packages: List user data packages

View source: R/list_user_data_packages.R

list_user_data_packagesR Documentation

List user data packages

Description

List all data packages (including their revision values) uploaded to the repository by a particular user, specified by a distinguished name. Data packages that were uploaded by the specified user but have since been deleted are excluded from the list.

Usage

list_user_data_packages(edi_id, env = "production")

Arguments

edi_id

(character) The EDI ID of the user. An EDI ID can be obtained from the EDI Identity and Access Manager (https://auth.edirepository.org/auth/ui/signin).

env

(character) Repository environment. Can be: "production", "staging", or "development".

Value

(character) Data package identifiers belonging to a edi_id

See Also

Other Listing: list_data_descendants(), list_data_entities(), list_data_package_identifiers(), list_data_package_revisions(), list_data_package_scopes(), list_data_sources(), list_deleted_data_packages(), list_recent_changes(), list_recent_uploads(), list_service_methods()

Examples

## Not run: 

# List user data packages
edi_id <- "EDI-543afa80c859825d35d37d9111c24a4a65a0ff9e"
packageIds <- list_user_data_packages(edi_id)
packageIds
#> [1] "edi.948.1" "edi.949.1"

## End(Not run)

EDIutils documentation built on May 6, 2026, 9:06 a.m.