List all data packages (including their revision values)
uploaded to the repository by a particular user, specified by a
distinguished name. Data packages that were uploaded by the specified user
but have since been deleted are excluded from the list.
if (FALSE) {
# List user data packagesedi_id <- "EDI-543afa80c859825d35d37d9111c24a4a65a0ff9e"packageIds <- list_user_data_packages(edi_id)
packageIds
#> [1] "edi.948.1" "edi.949.1"}